@@ -1,7 +1,7 @@
 package Email::MIME::Kit;
-our $VERSION = '2.093070';
-
-
+BEGIN {
+  $Email::MIME::Kit::VERSION = '2.101960';
+}
 require 5.008;
 use Moose;
 use Moose::Util::TypeConstraints;
@@ -118,8 +118,9 @@ sub assemble {
 
   my $email = $self->assembler->assemble($copied_stash);   
 
-  $email->header_set('Message-ID' => $self->_generate_content_id)
-    unless $email->header_set;
+  my $header = $email->header('Message-ID');
+  $email->header_set('Message-ID' => $self->_generate_content_id->in_brackets)
+    unless defined $header;
 
   return $email;
 }
@@ -157,7 +158,7 @@ has assembler => (
 );
 
 sub _generate_content_id {
-  Email::MessageID->new->as_string;
+  Email::MessageID->new;
 }
 
 
@@ -174,7 +175,7 @@ Email::MIME::Kit - build messages from templates
 
 =head1 VERSION
 
-version 2.093070
+version 2.101960
 
 =head1 SYNOPSIS
 
@@ -266,11 +267,11 @@ The development of this code was sponsored by Pobox.com.  Thanks, Pobox!
 
 =head1 AUTHOR
 
-  Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2009 by Ricardo Signes.
+This software is copyright (c) 2010 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
